Slot: attributes - LinkML Model

# Slot: attributes

Inline definition of slots

URI: linkml:attributes

## Domain and Range

ClassDefinition → 0..* SlotDefinition

## Parents

## Children

## Used by

- ClassDefinition

## Other properties

Comments: |  | attributes are an alternative way of defining new slots. An attribute adds a slot to the global space in the form __ (lower case, double underscores). Attributes can be specialized via slot_usage.